@@ -27,7 +27,9 @@ MIT_Params = {
             'Kp_max': 500.0,
             'Kd_min': 0.0,
             'Kd_max': 5.0,
-            'NM_PER_AMP': 0.091, # Need to use their constant for current conversion -- 0.146 by our calcs, 0.091 by theirs. At output leads to 1.31 by them and 1.42 by us.
+            'Kt_TMotor' : 0.091, # from TMotor website (actually 1/Kvll)
+            'Current_Factor' : 0.58925565098, # to correct the qaxis current (1/(1.2*sqrt(2)))
+            'NM_PER_AMP': 0.11, # Need to use their constant for current conversion -- 0.146 by our calcs, 0.091 by theirs. At output leads to 1.31 by them and 1.42 by us.
             'GEAR_RATIO': 9.0, # hence the 9 in the name
             'Use_derived_torque_constants': True, # true if you have a better model
             #         bias            nonlinear torque const multipliers  coulomb friction   gear friction
@@ -206,6 +208,9 @@ class MIT_command:
 
 # motor state from the controller, uneditable named tuple
 MIT_motor_state = namedtuple('motor_state', 'position velocity current temperature error')
+"""
+Motor state from the controller, uneditable named tuple
+"""
 
 # python-can listener object, with handler to be called upon reception of a message on the CAN bus
 class motorListener(can.Listener):
@@ -238,9 +243,16 @@ class motorListener(can.Listener):
 class CAN_Manager(object):
     """A class to manage the low level CAN communication protocols"""
     debug = False
+    """
+    Set to true to display every message sent and recieved for debugging.
+    """
     # Note, defining singletons in this way means that you cannot inherit
     # from this class, as apparently __init__ for the subclass will be called twice
     _instance = None
+    """
+    Used to keep track of one instantation of the class to make a singleton object
+    """
+    
     def __new__(cls):
         """
         Makes a singleton object to manage a socketcan_native CAN bus.
@@ -261,6 +273,9 @@ class CAN_Manager(object):
         return cls._instance
 
     def __init__(self):
+        """
+        ALl initialization happens in __new__
+        """
         pass
         
     def __del__(self):
@@ -476,4 +491,4 @@ class CAN_Manager(object):
                 print('  Temp: ' + str(temp))
                 print('  Error: ' + str(error))
 
-        return MIT_motor_state(position, velocity, current/(MIT_Params[motor_type]['NM_PER_AMP']*MIT_Params[motor_type]['GEAR_RATIO']), temp, error)
+        return MIT_motor_state(position, velocity, MIT_Params[motor_type]['Current_Factor']*current/(MIT_Params[motor_type]['GEAR_RATIO']*MIT_Params[motor_type]['Kt_TMotor']), temp, error)
