@@ -6,8 +6,6 @@ import traceback
 from collections import namedtuple
 from enum import Enum
 from math import isfinite
-from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
-from NeuroLocoMiddleware.SysID import Chirp
 import numpy as np
 import warnings
 
@@ -23,6 +21,9 @@ LOG_VARIABLES = [
 
 # possible states for the controller
 class _TMotorManState(Enum):
+    """
+    An Enum to keep track of different control states
+    """
     IDLE = 0
     IMPEDANCE = 1
     CURRENT = 2
@@ -46,18 +47,16 @@ class TMotorManager():
             motor_type: The type of motor being controlled, ie AK80-9.
             motor_ID: The CAN ID of the motor.
             CSV_file: A CSV file to output log info to. If None, no log will be recorded.
-            log_vars: The variables to log as a python list. The full list of possibilities is:
-                [
-                    "output_angle", 
-                    "output_velocity", 
-                    "output_acceleration", 
-                    "current",
-                    "output_torque",
-                    "motor_angle", 
-                    "motor_velocity", 
-                    "motor_acceleration", 
-                    "motor_torque"
-                ]
+            log_vars: The variables to log as a python list. The full list of possibilities is
+            - "output_angle"
+            - "output_velocity"
+            - "output_acceleration"
+            - "current"
+            - "output_torque"
+            - "motor_angle"
+            - "motor_velocity"
+            - "motor_acceleration"
+            - "motor_torque"
             use_torque_compensation: Enables a more complex torque model to compensate for friction, if available
         """
         self.type = motor_type
@@ -73,7 +72,7 @@ class TMotorManager():
         self._times_past_current_limit = 0
         self._times_past_velocity_limit = 0
         self._angle_threshold = MIT_Params[self.type]['P_max'] - 2.0 # radians, only really matters if the motor's going super fast
-        self._current_threshold = MIT_Params[self.type]['T_max'] - 2.0 # A, only really matters if the motor's going super fast
+        self._current_threshold = MIT_Params[self.type]['T_max']/(MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor']) - 4.0 # A, only really matters if the current changes quick
         self._velocity_threshold = MIT_Params[self.type]['V_max'] - 2.0 # radians, only really matters if the motor's going super fast
         self._old_pos = None
         self._old_curr = 0.0
@@ -120,6 +119,8 @@ class TMotorManager():
         self.power_on()
         self._send_command()
         self._entered = True
+        if not self.check_can_connection():
+            raise RuntimeError("Device not connected: " + str(self.device_info_string()))
         return self
 
     def __exit__(self, etype, value, tb):
@@ -182,9 +183,9 @@ class TMotorManager():
             self._command_sent = False
 
         # artificially extending the range of the position, current, and velocity that we track
-        P_max = MIT_Params[self.type]['P_max']
-        I_max =  MIT_Params[self.type]['T_max']/(MIT_Params[self.type]['NM_PER_AMP']*MIT_Params[self.type]['GEAR_RATIO'])
-        V_max =  MIT_Params[self.type]['V_max']
+        P_max = MIT_Params[self.type]['P_max']+ 0.01
+        I_max =  MIT_Params[self.type]['T_max']/(MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor']) + 0.01
+        V_max =  MIT_Params[self.type]['V_max']+ 0.01
 
         if self._old_pos is None:
             self._old_pos = self._motor_state_async.position
@@ -243,11 +244,11 @@ class TMotorManager():
         doesn't account for friction losses.
         """
         if self._control_state == _TMotorManState.FULL_STATE:
-            self._canman.MIT_controller(self.ID,self.type, self._command.position, self._command.velocity, self._command.kp, self._command.kd, self._command.current*MIT_Params[self.type]['NM_PER_AMP']*MIT_Params[self.type]['GEAR_RATIO'])
+            self._canman.MIT_controller(self.ID,self.type, self._command.position, self._command.velocity, self._command.kp, self._command.kd, self._command.current*MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor'])
         elif self._control_state == _TMotorManState.IMPEDANCE:
             self._canman.MIT_controller(self.ID,self.type, self._command.position, self._command.velocity, self._command.kp, self._command.kd, 0.0)
         elif self._control_state == _TMotorManState.CURRENT:
-            self._canman.MIT_controller(self.ID, self.type, 0.0, 0.0, 0.0, 0.0, self._command.current*MIT_Params[self.type]['NM_PER_AMP']*MIT_Params[self.type]['GEAR_RATIO'])
+            self._canman.MIT_controller(self.ID, self.type, 0.0, 0.0, 0.0, 0.0, self._command.current*MIT_Params[self.type]['GEAR_RATIO']*MIT_Params[self.type]['Kt_TMotor']/MIT_Params[self.type]['Current_Factor'])
         elif self._control_state == _TMotorManState.IDLE:
             self._canman.MIT_controller(self.ID,self.type, 0.0, 0.0, 0.0, 0.0, 0.0)
         elif self._control_state == _TMotorManState.SPEED:
@@ -337,7 +338,7 @@ class TMotorManager():
             a_hat = MIT_Params[self.type]['a_hat']
             kt = MIT_Params[self.type]["NM_PER_AMP"]
             gr = MIT_Params[self.type]["GEAR_RATIO"]
-            ϵ = 1.0
+            ϵ = 0.1
             i = self.get_current_qaxis_amps()
             v = self.get_motor_velocity_radians_per_second()
 
@@ -546,7 +547,7 @@ class TMotorManager():
     # Pretty stuff
     def __str__(self):
         """Prints the motor's device info and current"""
-        return self.device_info_string() + " | Position: " + str(round(self.θ,3)) + " rad | Velocity: " + str(round(self.θd ,3)) + " rad/s | current: " + str(round(self.i,3)) + " A | torque: " + str(round(self.τ,3)) + " Nm"
+        return self.device_info_string() + " | Position: " + '{: 1f}'.format(round(self.θ,3)) + " rad | Velocity: " + '{: 1f}'.format(round(self.θd,3)) + " rad/s | current: " + '{: 1f}'.format(round(self.i,3)) + " A | torque: " + '{: 1f}'.format(round(self.τ,3)) + " Nm"
 
     def device_info_string(self):
         """Prints the motor's ID and device type."""
